@@ -1,4 +1,4 @@
-# $Id: Alias.pm 46898 2017-08-24 11:53:09Z wsl $
+# $Id: Alias.pm 47135 2017-11-02 10:52:00Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/Database/Alias.pm $
 
 package UvT::Kiki::Database::Alias;
@@ -253,11 +253,11 @@ sub diff {
 		}
 
 		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @old_destinations) {
-			$diff += " \t$destination\n" if exists $destinations{$destination};
+			$diff .= " \t$destination\n" if exists $destinations{$destination};
 		}
 
 		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @destinations) {
-			$diff += "+\t$destination\n" unless exists $old_destinations{$destination};
+			$diff .= "+\t$destination\n" unless exists $old_destinations{$destination};
 		}
 	} else {
 		foreach my $destination (sort { lc($a) cmp lc($b) || $a cmp $b } @destinations) {
