@@ -1,4 +1,4 @@
-# $Id: Document.pm 37636 2012-08-24 15:02:42Z wsl $
+# $Id: Document.pm 42150 2014-09-04 11:27:31Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/lib/UvT/Kiki/WS/Document.pm $
 
 use strict;
@@ -8,7 +8,6 @@ use utf8;
 package UvT::Kiki::WS::Document;
 
 use JSON;
-use Data::Dumper;
 
 use Xyzzy::Document -self;
 
@@ -57,7 +56,7 @@ sub ghetto_json() {
 }
 
 sub serialize {
-	ghetto_json($self->json);
-	our $json //= JSON->new->utf8->allow_blessed->convert_blessed;
-	return new Xyzzy::Response(mimetype => 'application/json', content => $json->encode($self->json));
+#	ghetto_json($self->json);
+	our $encoder //= JSON->new->utf8->allow_blessed->convert_blessed;
+	return new Xyzzy::Response(mimetype => 'application/json', content => $encoder->encode($self->json));
 }
